Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1443)

Unified Diff: sdk/lib/_internal/pub/lib/src/barback.dart

Issue 179043004: Allow a wider pub constraint on barback. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: code review Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | sdk/lib/_internal/pub/lib/src/solver/backtracking_solver.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/_internal/pub/lib/src/barback.dart
diff --git a/sdk/lib/_internal/pub/lib/src/barback.dart b/sdk/lib/_internal/pub/lib/src/barback.dart
index fa1ed9e76cd4d3ee3fd858d253b9c186b7217f6e..ffd301f8c81a60d395640816a51c873b1ef20759 100644
--- a/sdk/lib/_internal/pub/lib/src/barback.dart
+++ b/sdk/lib/_internal/pub/lib/src/barback.dart
@@ -12,10 +12,10 @@ import 'package:path/path.dart' as path;
import 'utils.dart';
import 'version.dart';
/// The currently supported version of the Barback package that this version of
/// pub works with.
///
-/// Pub implicitly constrains barback to this version or later patch versions.
+/// Pub implicitly constrains barback to these versions.
///
/// Barback is in a unique position. Pub imports it, so a copy of Barback is
/// physically included in the SDK. Packages also depend on Barback (from
@@ -31,7 +31,7 @@ import 'version.dart';
///
/// Whenever a new non-patch version of barback is published, this *must* be
/// incremented to synchronize with that.
-final supportedVersion = new Version(0, 12, 0);
+final supportedVersions = new VersionConstraint.parse(">=0.11.0 <0.13.0");
/// A list of the names of all built-in transformers that pub exposes.
const _BUILT_IN_TRANSFORMERS = const ['\$dart2js'];
« no previous file with comments | « no previous file | sdk/lib/_internal/pub/lib/src/solver/backtracking_solver.dart » ('j') | no next file with comments »
@@ -12,10 +12,10 @@ import 'package:path/path.dart' as path;
import 'utils.dart';
import 'version.dart';
-/// The currently supported version of the Barback package that this version of
+/// The currently supported versions of the Barback package that this version of
/// pub works with.
///

Powered by Google App Engine
This is Rietveld 408576698